% Fork de https://github.com/jjonw/furgmpu
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{furgmpu}[2023/06/05 Classe para trabalhos da MPU]

% Tipo artigo com fonte em 12pt e sem alternância de lado
\LoadClass[12pt,oneside]{article}

% Define tamanho A4, margens e posicionamentos de cabeçalho e rodapé
\RequirePackage[
	 paper=a4paper
	,top=2.5cm
	,right=2cm
	,bottom=4cm
	,left=3cm
	,headheight=2cm
	,headsep=0.4cm
	,footskip=0.5cm
]{geometry}

% Espaçamento antes de cabeçalho?
\addtolength{\voffset}{0.9cm}
% Codificação do conteúdo é em UTF-8
\RequirePackage[utf8]{inputenc}
% Tipo de fonte de 8 bits
\RequirePackage[T1]{fontenc}
% Cálculo de páginas
\RequirePackage{lastpage}
% Fonte semelhante à Helvetica
\RequirePackage{helvet}
% Seta fonte padrão a sem pé
\renewcommand{\familydefault}{\sfdefault}
% ?
\RequirePackage{etoolbox}
\patchcmd{\thebibliography}{\section*}{\section}{}{}
% Referências no padrão ABNT
\RequirePackage[alf,abnt-emphasize=bf]{abntex2cite}
% Configura alguns espaçamentos?
\RequirePackage{booktabs}
\RequirePackage{titling}
\pretitle{\center\vspace{-1.4cm}}
\preauthor{\flushright}
\postauthor{\vskip -1.0cm}
\posttitle{\vskip 0.4cm}
% Inclusão de imagens
\RequirePackage{graphicx}
% Formatação de seções?
\RequirePackage{sectsty}
\sectionfont{\fontsize{12}{12}\selectfont}
% Formatação de seções?
\RequirePackage{titlesec}
\titlespacing{\section}{0pt}{24pt}{0pt}
% Identação de primeira linha
\setlength{\parindent}{1.25cm}
% Gestão de cores
\RequirePackage{xcolor}
\definecolor{mpularanja}{RGB}{237,135,62}
\definecolor{mpulilas}{RGB}{84,47,90}
% Desenhos vetoriais
\RequirePackage{tikz}
% Cabeçalho e rodapé
\RequirePackage{fancyhdr}
% Mesclar linhas
\RequirePackage{multirow}
% Configura cabeçalho e rodapé
\fancypagestyle{plain}{
	% Reta configurações
	\fancyhf{}
	% Linhas separando do conteúdo com tamanho 0
	\renewcommand{\headrulewidth}{0pt}
	\renewcommand{\footrulewidth}{0pt}
	% Parte do meio do cabeçalho
	\fancyhead[C]{
		% Tabela
		\begin{tabular}{ c p{2.5mm} c }
			% Célula até a 4ª linha
			\multirow{4}{*}{
				% Imagem vetorial a partir do logo
				\begin{tikzpicture}[scale=0.175]
					\fill [mpularanja,even odd rule]
						%Circs
						(4.1,-0.02) circle (0.45) (2.91,2.88) circle (0.45) (0.02,4.10) circle (0.45) (-2.88,2.91) circle (0.45) (-4.10,0.02) circle (0.45) (-2.91,-2.88) circle (0.45) (-0.02,-4.10) circle (0.45) (2.88,-2.91) circle (0.45)
						%Silh
						(-0.1,0.26) .. controls (1,1.09) and (3.01,1.53) .. (3.41,-0.71) .. controls (3.28,0.59) and (4.52,1.47) .. (5.19,-0.21) .. controls (4.77,2.29) and (1.15,2.32) .. cycle
						(-0.25,0.11) .. controls (-0.06,1.48) and (1.05,3.21) .. (2.91,1.91) .. controls (1.90,2.74) and (2.16,4.24) .. (3.82,3.52) .. controls (1.75,4.99) and (-0.83,2.45) .. cycle
						(-0.26,-0.10) .. controls (-1.09,1.00) and (-1.53,3.01) .. (0.71,3.41) .. controls (-0.59,3.28) and (-1.47,4.52) .. (0.21,5.19) .. controls (-2.29,4.77) and (-2.32,1.15) .. cycle
						(-0.11,-0.25) .. controls (-1.48,-0.06) and (-3.21,1.05) .. (-1.91,2.91) .. controls (-2.74,1.90) and (-4.24,2.16) .. (-3.52,3.82) .. controls (-4.99,1.75) and (-2.45,-0.83) .. cycle
						(0.10,-0.26) .. controls (-1.00,-1.09) and (-3.01,-1.53) .. (-3.41,0.71) .. controls (-3.28,-0.59) and (-4.52,-1.47) .. (-5.19,0.21) .. controls (-4.77,-2.29) and (-1.15,-2.32) .. cycle
						(0.25,-0.11) .. controls (0.06,-1.48) and (-1.05,-3.21) .. (-2.91,-1.91) .. controls (-1.90,-2.74) and (-2.16,-4.24) .. (-3.82,-3.52) .. controls (-1.75,-4.99) and (0.83,-2.45) .. cycle
						(0.26,0.10) .. controls (1.09,-1.00) and (1.53,-3.01) .. (-0.71,-3.41) .. controls (0.59,-3.28) and (1.47,-4.52) .. (-0.21,-5.19) .. controls (2.29,-4.77) and (2.32,-1.15) .. cycle
						(0.11,0.25) .. controls (1.48,0.06) and (3.21,-1.05) .. (1.91,-2.91) .. controls (2.74,-1.90) and (4.24,-2.16) .. (3.52,-3.82) .. controls (4.99,-1.75) and (2.45,0.83) .. cycle
						% Editar edição
						%2
						(6.32,2.47) -- (7.04,2.47) -- (7.04,2.6) -- (6.52,2.6) .. controls (7.43,3.4) and (6.91,3.86) .. (6.36,3.58) -- (6.37,3.42) .. controls (6.83,3.68) and (7.15,3.39) .. (6.32,2.59) -- cycle
						%2
						(7.29,2.47) -- (8.01,2.47) -- (8.01,2.6) -- (7.49,2.6) .. controls (8.4,3.4) and (7.88,3.86) .. (7.33,3.58) -- (7.34,3.42) .. controls (7.8,3.68) and (8.12,3.39) .. (7.29,2.59) -- cycle
						%a
						(8.71,3.04) -- (8.71,3.39) .. controls (8.7,3.64) and (8.54,3.7) .. (8.26,3.6) -- (8.26,3.5) .. controls (8.47,3.61) and (8.62,3.55) .. (8.59,3.4) .. controls (7.84,3.47) and (8.33,2.77) .. (8.61,3.15) -- (8.61,3.04) -- cycle
						(8.6,3.33) .. controls (7.97,3.34) and (8.55,2.86) .. cycle
						%M
						(9.45,2.48) -- (9.58,2.48) -- (9.58,3.51) -- (9.97,2.48) -- (10.12,2.48) -- (10.52,3.5) -- (10.52,2.47) -- (10.68,2.47) -- (10.68,3.63) -- (10.43,3.63) -- (10.05,2.64) -- (9.68,3.63) -- (9.44,3.63) -- cycle
						%O
						(10.91,3.06) .. controls (10.91,3.86) and (11.97,3.86) .. (11.97,3.06) .. controls (11.97,2.24) and (10.91,2.24) .. cycle
						(11.08,3.06) .. controls (11.08,3.69) and (11.8,3.69) .. (11.8,3.06) .. controls (11.8,2.42) and (11.08,2.42) .. cycle
						%S
						(12.79,3.48) -- (12.79,3.61) .. controls (12.09,3.81) and (12,3.24) .. (12.41,3.02) .. controls (12.93,2.71) and (12.57,2.47) .. (12.17,2.64) -- (12.17,2.47) .. controls (12.85,2.3) and (13.05,2.89) .. (12.6,3.11) .. controls (12.18,3.31) and (12.27,3.63) .. cycle
						%T
						(13.27,2.47) -- (13.43,2.47) -- (13.43,3.5) -- (13.76,3.5) -- (13.76,3.62) -- (12.94,3.62) -- (12.94,3.5) -- (13.27,3.5) -- cycle
						%R
						(13.91,2.47) -- (14.07,2.47) -- (14.07,2.97) .. controls (14.2,3) and (14.3,3) .. (14.37,2.87) -- (14.53,2.47) -- (14.7,2.47) -- (14.51,2.9) .. controls (14.47,2.97) and (14.45,3.03) .. (14.37,3.05) .. controls (14.72,3.05) and (14.74,3.63) .. (14.3,3.62) -- (13.91,3.62) -- cycle
						(14.07,3.1) -- (14.2,3.1) .. controls (14.57,3.1) and (14.57,3.5) .. (14.2,3.5) -- (14.07,3.5) -- cycle
						%A
						(14.74,2.48) -- (14.91,2.48) -- (15.01,2.78) -- (15.56,2.78) -- (15.67,2.48) -- (15.85,2.48) -- (15.4,3.62) -- (15.2,3.62) -- cycle
						(15.05,2.89) -- (15.52,2.89) -- (15.3,3.47) -- cycle
						%D
						(16.47,2.47) -- (16.83,2.47) .. controls (17.58,2.47) and (17.58,3.62) .. (16.84,3.62) -- (16.47,3.62) -- cycle
						(16.62,2.6) -- (16.83,2.6) .. controls (17.35,2.6) and (17.35,3.5) .. (16.84,3.5) -- (16.62,3.5) -- cycle
						%A
						(17.48,2.48) -- (17.65,2.48) -- (17.75,2.78) -- (18.3,2.78) -- (18.41,2.48) -- (18.59,2.48) -- (18.14,3.62) -- (17.94,3.62) -- cycle
						(17.79,2.89) -- (18.26,2.89) -- (18.04,3.47) -- cycle
					;
					\fill [mpulilas,even odd rule]
						%P
						(6.32,-0.98) -- (6.74,-0.97) -- (6.74,0.12) -- (7.02,0.12) .. controls (7.77,0.12) and (7.77,1.71) .. (7.02,1.71) -- (6.32,1.71) -- cycle
						(6.73,0.5) -- (6.94,0.5) .. controls (7.25,0.5) and (7.25,1.33) .. (6.94,1.33) -- (6.73,1.33) -- cycle
						%R
						(7.86,-0.98) -- (8.28,-0.98) -- (8.28,0.15) -- (8.47,0.15) -- (8.73,-0.98) -- (9.16,-0.98) -- (8.85,0.26) .. controls (9.21,0.46) and (9.313,1.71) .. (8.56,1.71) -- (7.86,1.71) -- cycle
						(8.27,0.54) -- (8.48,0.54) .. controls (8.79,0.54) and (8.79,1.33) .. (8.48,1.33) -- (8.27,1.33) -- cycle
						%O
						(10.69,1.11) .. controls (10.69,1.97) and (9.42,1.97) .. (9.42,1.11) -- (9.42,-0.35) .. controls (9.42,-1.28) and (10.69,-1.28) .. (10.69,-0.35) -- cycle
						(10.27,1.11) .. controls (10.27,1.49) and (9.84,1.49) .. (9.84,1.11) -- (9.84,-0.35) .. controls (9.84,-0.78) and (10.27,-0.78) .. (10.27,-0.35) -- cycle
						%D
						(11.07,-0.98) -- (11.71,-0.98) .. controls (12.1,-0.98) and (12.32,-0.76) .. (12.32,-0.2) -- (12.32,1) .. controls (12.32,1.5) and (12.1,1.7) .. (11.72,1.71) -- (11.07,1.71) -- cycle
						(11.48,-0.6) -- (11.66,-0.6) .. controls (11.81,-0.6) and (11.91,-0.5) .. (11.91,-0.31) -- (11.91,1.03) .. controls (11.91,1.2) and (11.8,1.32) .. (11.66,1.32) -- (11.48,1.32) -- cycle
						%U
						(12.68,1.71) -- (13.1,1.71) -- (13.1,-0.43) .. controls (13.1,-0.72) and (13.53,-0.72) .. (13.53,-0.43) -- (13.53,1.71) -- (13.95,1.71) -- (13.95,-0.34) .. controls (13.95,-1.29) and (12.68,-1.29) .. (12.68,-0.34) -- cycle
						%Ç
						(15.17,0.82) -- (15.58,0.82) -- (15.58,1.16) .. controls (15.58,1.97) and (14.31,1.97) .. (14.31,1.16) -- (14.31,-0.33) .. controls (14.31,-0.78) and (14.58,-1.03) .. (14.81,-1.03) -- (14.72,-1.25) .. controls (15.16,-1.29) and (14.88,-1.57) .. (14.54,-1.43) -- (14.54,-1.57) .. controls (15.32,-1.78) and (15.63,-1.16) .. (14.89,-1.13) -- (14.93,-1.05) .. controls (15.32,-1.05) and (15.58,-0.76) .. (15.58,-0.39) -- (15.58,-0.02) -- (15.17,-0.02) -- (15.17,-0.41) .. controls (15.17,-0.77) and (14.72,-0.77) .. (14.72,-0.41) -- (14.72,1.11) .. controls (14.72,1.5) and (15.17,1.5) .. (15.17,1.11) -- cycle
						%~
						(16,1.87) -- (16.2,1.87) .. controls (16.2,2.27) and (16.88,1.43) .. (16.94,2.24) -- (16.76,2.24) .. controls (16.76,1.83) and (16.1,2.68) .. cycle
						%A
						(15.76,-0.98) -- (16.17,-0.98) -- (16.26,-0.4) -- (16.68,-0.4) -- (16.76,-0.98) -- (17.19,-0.98) -- (16.75,1.71) -- (16.2,1.71) -- cycle
						(16.3,-0.03) -- (16.63,-0.03) -- (16.47,1.15) -- cycle
						%O
						(18.65,1.11) .. controls (18.65,1.97) and (17.38,1.97) .. (17.38,1.11) -- (17.38,-0.35) .. controls (17.38,-1.28) and (18.65,-1.28) .. (18.65,-0.35) -- cycle
						(18.23,1.11) .. controls (18.23,1.49) and (17.8,1.49) .. (17.8,1.11) -- (17.8,-0.35) .. controls (17.8,-0.78) and (18.23,-0.78) .. (18.23,-0.35) -- cycle
						%U
						(6.27,-2.04) -- (6.57,-2.04) -- (6.57,-3.52) .. controls (6.57,-3.79) and (6.88,-3.79) .. (6.88,-3.51) -- (6.88,-2.04) -- (7.18,-2.04) -- (7.18,-3.52) .. controls (7.18,-4.19) and (6.27,-4.19) .. (6.27,-3.51) -- cycle
						%N
						(7.48,-3.97) -- (7.76,-3.97) -- (7.76,-2.81) -- (8.15,-3.97) -- (8.42,-3.97) -- (8.42,-2.04) -- (8.14,-2.04) -- (8.14,-3.25) -- (7.73,-2.04) -- (7.48,-2.04) -- cycle
						%I
						(8.74,-2.04) -- (9.02,-2.04) -- (9.02,-3.97) -- (8.74,-3.97) -- cycle
						%V
						(9.21,-2.04) -- (9.49,-2.04) -- (9.7,-3.43) -- (9.91,-2.04) -- (10.21,-2.04) -- (9.86,-3.96) -- (9.55,-3.97) -- cycle
						%E
						(10.38,-3.96) -- (11.15,-3.96) -- (11.15,-3.68) -- (10.67,-3.68) -- (10.67,-3.1) -- (11.02,-3.1) -- (11.02,-2.83) -- (10.67,-2.83) -- (10.67,-2.32) -- (11.15,-2.32) -- (11.15,-2.04) -- (10.38,-2.04) -- cycle
						%R
						(11.39,-3.96) -- (11.67,-3.96) -- (11.67,-3.16) -- (11.83,-3.16) -- (12,-3.96) -- (12.31,-3.96) -- (12.09,-3.08) .. controls (12.3,-2.99) and (12.53,-2.04) .. (11.8,-2.04) -- (11.39,-2.04) -- cycle
						(11.69,-2.88) -- (11.83,-2.88) .. controls (12.04,-2.88) and (12.04,-2.32) .. (11.83,-2.32) -- (11.69,-2.32) -- cycle
						%S
						(13.1,-2.53) -- (13.37,-2.49) .. controls (13.31,-1.79) and (12.35,-1.87) .. (12.49,-2.63) .. controls (12.59,-2.95) and (12.91,-3.14) .. (13.04,-3.36) .. controls (13.27,-3.76) and (12.76,-3.9) .. (12.71,-3.44) -- (12.43,-3.48) .. controls (12.5,-4.33) and (13.64,-4.08) .. (13.34,-3.29) .. controls (13.19,-2.99) and (12.82,-2.73) .. (12.77,-2.56) .. controls (12.71,-2.25) and (13.05,-2.16) .. cycle
						%I
						(13.62,-2.04) -- (13.9,-2.04) -- (13.9,-3.97) -- (13.62,-3.97) -- cycle
						%T
						(14.35,-3.97) -- (14.64,-3.97) -- (14.64,-2.31) -- (14.95,-2.31) -- (14.95,-2.04) -- (14.03,-2.04) -- (14.03,-2.31) -- (14.35,-2.31) -- cycle
						%´
						(15.32,-1.93) -- (15.54,-1.93) -- (15.78,-1.65) -- (15.44,-1.65) -- cycle
						%A
						(14.96,-3.97) -- (15.25,-3.97) -- (15.31,-3.54) -- (15.62,-3.54) -- (15.68,-3.97) -- (15.98,-3.97) -- (15.66,-2.04) -- (15.28,-2.04) -- cycle
						(15.35,-3.28) -- (15.58,-3.28) -- (15.47,-2.44) -- cycle
						%R
						(16.15,-3.96) -- (16.43,-3.96) -- (16.43,-3.16) -- (16.59,-3.16) -- (16.76,-3.96) -- (17.07,-3.96) -- (16.85,-3.08) .. controls (17.06,-2.99) and (17.29,-2.04) .. (16.56,-2.04) -- (16.15,-2.04) -- cycle
						(16.45,-2.88) -- (16.59,-2.88) .. controls (16.8,-2.88) and (16.8,-2.32) .. (16.59,-2.32) -- (16.45,-2.32) -- cycle
						%I
						(17.3,-2.04) -- (17.58,-2.04) -- (17.58,-3.97) -- (17.3,-3.97) -- cycle
						%A
						(17.75,-3.97) -- (18.04,-3.97) -- (18.1,-3.54) -- (18.41,-3.54) -- (18.47,-3.97) -- (18.77,-3.97) -- (18.45,-2.04) -- (18.07,-2.04) -- cycle
						(18.14,-3.28) -- (18.37,-3.28) -- (18.26,-2.44) -- cycle
					;
				\end{tikzpicture}
			}
			% Restante do cabeçalho
			&&\footnotesize Universidade Federal do Rio Grande – FURG\\
			% Editar edição
			&&\footnotesize 22ª Mostra da Produção Universitária – MPU\\
			&&\footnotesize Rio Grande/RS, Brasil, 25 a 27 de outubro de 2023\\
			&&\footnotesize ISSN: 2317-4420                                  
		\end{tabular}
	}
	% Número em rodapé
	\fancyfoot[R]{\thepage}
}

% Tipo de página
\pagestyle{plain}

% Comandos de título e de autores
\newcommand{\titulo}[1]{\title{\textbf{#1}}}
\newcommand{\autores}[4]{\author{{\normalsize{#1\\\vspace{0.5cm}#2\\#3\\#4}}}\date{\vspace{-4.2ex}}}
